package SLA4;

public abstract class DataTypeAbstraction {

	/**
	 * Returns an DataTypeAbstraction object of the requested type.
	 * If the type is unknown a DataTypeAbstractionDouble is returned.
	 * Which might be wrong :-(
	 * 
	 * @param type
	 * @param low
	 * @param high
	 * @return
	 */
	public static DataTypeAbstraction newInstance(String type)
	{
		switch (type)
		{
		case "Double":
			return new DataTypeAbstractionDouble();
		case "Integer":
		case "Long":
			return new DataTypeAbstractionInteger();
		case "Period":
			return new DataTypeAbstractionPeriod();
		}
		
		return new DataTypeAbstractionDouble();
	}
	
	/**
	 * Cast the specified object to the correct type, if possible.
	 * 
	 * @param o1
	 * @return
	 */
	public abstract Object cast(Object o1);
	
	/**
	 * Convert the specified String value to the target data type.
	 * I.e. Double, Long, Integer, etc.
	 */
	public abstract Object convert(String value);

	/**
	 * Returns the lowest value for the type.
	 * 
	 * @param value
	 * @return
	 */
	public abstract Object getLowest();
	
	/**
	 * Returns the highest value for the type.
	 * 
	 * @param value
	 * @return
	 */
	public abstract Object getHighest();
	
	/**
	 * Add two values and return the result.
	 * 
	 * @param o1
	 * @param o2
	 * @return
	 */
	public abstract Object add(Object o1, Object o2);
	
	/**
	 * Multiply two values and return the result.
	 * 
	 * @param o1
	 * @param o2
	 * @return
	 */
	public abstract Object mul(Object o1, Object o2);
	
	/**
	 * Divide two values and return the result.
	 * 
	 * @param o1
	 * @param o2
	 * @return
	 */
	public abstract Object div(Object o1, Object o2);
	
	/**
	 * Compare two values in a Greater than relation
	 * @param o1
	 * @param o2
	 * @return
	 */
	public abstract boolean gt(Object o1, Object o2);

	/**
	 * Compare two values in a Smaller than relation
	 * @param o1
	 * @param o2
	 * @return
	 */
	public abstract boolean lt(Object o1, Object o2);
	
	/**
	 * Compare two values in a Greater than or Equal relation
	 * @param o1
	 * @param o2
	 * @return
	 */
	public abstract boolean ge(Object o1, Object o2);

	/**
	 * Compare two values in a Smaller than or Equal relation
	 * @param o1
	 * @param o2
	 * @return
	 */
	public abstract boolean le(Object o1, Object o2);
	
	/**
	 * Convert a value to a String representation.
	 * @param o1
	 * @return
	 */
	public abstract String toString(Object o1);

}
