package SLA4;

public class Period {
	
	private static final long SECOND = 1000l;
	private static final long MINUTE = 60l * SECOND;
	private static final long HOUR	 = 60l * MINUTE;
	private static final long DAY	 = 24l * HOUR;
	
	private long timePeriod = 0l;
	
	public Period(String period)
	{
		this.parse(period);
	}

	public Period(long timePeriod)
	{
		this.timePeriod = timePeriod;
	}
	
	/**
	 * Period syntax: day
	 * 				| day " " [[hours:]minutes:]seconds[.millis]
	 * 				| [hours:]minutes]:seconds[.millis]
	 * 				| seconds.
	 * 				| seconds.millis
	 * 				| .millis
	 * 				;
	 * 
	 * @param period
	 * @return
	 */
	public long parse(String period)
	{
		period = period.trim();
		
		long p = 0l;
		
		int space = period.indexOf(' ');
		int colon = period.indexOf(':');
		int dot   = period.indexOf('.');
		//
		//	If no spaces, no colon and no dot, then there should only be number of days
		//
		if (colon == -1 && dot == -1 && space == -1)
		{
			p = new Long(period) * DAY;			
			this.timePeriod = p;

			return this.timePeriod;
		}

		//
		//	There is a number of days
		//
		if (space > 0 && (space < colon || space < dot))
		{
			String sDays = period.substring(0, space);
			p = new Long(sDays.trim()) * DAY;
		}
		
		if (dot > -1)
		{
			String sMilis = period.substring(dot+1);
			p = p + new Long(sMilis.trim());
		}
		else
		{
			dot = period.length();
		}
		
		String rest = period.substring(space+1, dot);
		String [] hms = rest.split(":");
		switch (hms.length)
		{
		case 3:
			p = p + new Long(hms[0].trim()) * HOUR;
			p = p + new Long(hms[1].trim()) * MINUTE;
			p = p + new Long(hms[2].trim()) * SECOND;
			break;
		case 2:
			p = p + new Long(hms[0].trim()) * MINUTE;
			p = p + new Long(hms[1].trim()) * SECOND;
			break;
		case 1:
			p = p + new Long(hms[0].trim()) * SECOND;
			break;
		}

		this.timePeriod = p;

		return this.timePeriod;
	}
	
	public long getTime()
	{
		return this.timePeriod;
	}
	
	public String toString()
	{
		long rest = timePeriod;
		long days = rest % DAY;
		rest = rest - days * DAY;
		long hours = rest % HOUR;
		rest = rest - hours * HOUR;
		long minutes = rest % MINUTE;
		rest = rest - minutes * MINUTE;
		long seconds = rest % SECOND;
		rest = rest - seconds * SECOND;
		long milis = rest;
		
		return String.format("%l$ %2$2:%3$2:$4$2.%5", days, hours, minutes, seconds, milis);
	}
}
