package SLA4;

import java.util.HashMap;

/**
 * Specifies meta data for the slo monitors contained in the the SLA Contract Monitor.
 * 
 * getTypes() returns an array with slo monitor instance type names
 * getSloAttribute() returns the attribute in  the slo monitor instance that refers to its corresponding slo,
 * which contains norm and penalty. 
 * 
 * @author Cor Hofman
 *
 */
public class SLOMonitorTypes {
	private final static String [] sloMonitorTypes = new String[] {
			"SLO Data Quality Monitor",
			"SLO Response Monitor",
			"SLO Simple Response Monitor",
			"SLO Volume Monitor",
	};
	/**
	 * Returns the type names of the slo monitors.
	 * 
	 * @return
	 */
	public static String [] getTypes()
	{
		return sloMonitorTypes;
	}

	private final static HashMap<String, String>sloAttributes = new HashMap<String, String>();
	static {
		sloAttributes.put("SLO Data Quality Monitor", "SLO Data Quality");
		sloAttributes.put("SLO Response Monitor", "SLO Response");
		sloAttributes.put("SLO Simple Response Monitor", "SLO Simple Response");
		sloAttributes.put("SLO Volume Monitor", "SLO Volume");
	}
	
	/**
	 * Returns the the attribute name within which the reference to the corresponding slo instance is stored.
	 * The slo instance referred to contains the norm and penalty specifications for which must be monitored.
	 * 
	 * @param sloMonitorType
	 * @return
	 */
	public static String getSloAttribute(String sloMonitorType)
	{
		return sloAttributes.get(sloMonitorType);
	}
}
