package SLA4;

import com.metamaxim.modelscope.callbacks.Event;
import com.metamaxim.modelscope.callbacks.Instance;

public class StartMonitoring extends Event {
	
	public void handleEvent()
	{
		//
		//	First handle the event itself
		//
		this.submitToModel();

		//
		//	Then submit the SLO specific "Start monitor" events for the SLO's within the SLA.
		//	The norm and penalty attributes are copied into the start monitor events,
		//	such that these value are available within the SLO Monitor instances.
		//
		//	Note that the SLOTypes.getTypes() returns all the SLO types.
		//	I.e. SLO Data Quality, SLO Response, SLO Volume, etc.
		//
		Instance sla = this.getInstance("SLA Contract");
		Instance slaMonitor = this.getInstance("SLA Contract Monitor");
		for (String sloType: SLOTypes.getTypes())
		{
			for (Instance slo: sla.selectByRef(sloType, "SLA Contract"))
			{
				switch (slo.getObjectType())
				{
				case "SLO Data Quality":
					Event startMonitoringDataQuality = this.createEvent("Start Monitoring Data Quality");
					startMonitoringDataQuality.setInstance("SLA Contract Monitor", slaMonitor);
					startMonitoringDataQuality.setInstance("SLO", slo);
					startMonitoringDataQuality.setNewInstance("SLO Data Quality Monitor", "SLO Data Quality Monitor");
					startMonitoringDataQuality.submitToModel();
					break;
					
				case "SLO Response":
					Event startMonitoringResponse = this.createEvent("Start Monitoring Response");
					startMonitoringResponse.setInstance("SLA Contract Monitor", slaMonitor);
					startMonitoringResponse.setInstance("SLO", slo);
					startMonitoringResponse.setNewInstance("SLO Response Monitor", "SLO Response Monitor");
					startMonitoringResponse.submitToModel();			
					break;
					
				case "SLO Simple Response":
					Event startMonitoringSimpleResponse = this.createEvent("Start Monitoring Simple Response");
					startMonitoringSimpleResponse.setInstance("SLA Contract Monitor", slaMonitor);
					startMonitoringSimpleResponse.setInstance("SLO", slo);
					startMonitoringSimpleResponse.setNewInstance("SLO Simple Response Monitor", "SLO Simple Response Monitor");
					startMonitoringSimpleResponse.submitToModel();			
					break;
					
				case "SLO Volume":
					Event startMonitoringVolume = this.createEvent("Start Monitoring Volume");
					startMonitoringVolume.setInstance("SLA Contract Monitor", slaMonitor);
					startMonitoringVolume.setInstance("SLO", slo);
					startMonitoringVolume.setNewInstance("SLO Volume Monitor", "SLO Volume Monitor");
					startMonitoringVolume.submitToModel();			
					break;
				}
			}
		}
	}

}
